# CHANGELOG


## v0.1.0 (2026-01-09)

### Features

- Simple launch file to demonstrate usage
  ([`4ee8761`](https://github.com/bec-project/bec_launcher/commit/4ee87619a2dad87a8cd6bd2a28bc3f8b7b05af14))

### Refactoring

- Enhance type safety by introducing DeploymentDict for deployment names
  ([`47e47da`](https://github.com/bec-project/bec_launcher/commit/47e47dac3cf3aaab5084bc4e32fbd194bf55f54d))
